<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kab">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Chella Ddihi</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Ddihi di dihson</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Chella Ddihi</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Ddihi di xefefi</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Ddihi di xefefi</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Mnusuli di dihson</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Chella</translation>
    </message>
</context>
</TS>